<%! from crab.util.web import abbr %> <%inherit file="base.html"/> <%block name="links"> ${info['host'] | h} ${info['user'] | h} % if info['crabid'] is not None: ${info['crabid'] | h} % else: ${info['command'] | abbr} % endif configuration % if config is None: % if orphan:

## Re-link Orphaned Job Configuration

There are orphaned configurations, relating to deleted jobs.

If this job is the continuation of one which has been deleted, its configuration can be transferred by selecting it for re-linking.

% endif

## Add New Job Configuration

% else:

## Edit Job Configuration

% endif

Any parameter which is left blank here will use the default value.

1. Grace period minutes
2. Time-out minutes